declare namespace _default {
    export const BOTTOM_LEFT: string;
    export const BOTTOM_RIGHT: string;
    export const TOP_LEFT: string;
    export const TOP_RIGHT: string;
}
export default _default;
//# sourceMappingURL=IconOrigin.d.ts.map